# mira

**IMPORTANT**: mira is in pre-release. The API is still under development and subject to change. In addition, there are likely bugs in implementations of some of the object detection models. As with all works-in-progress, please use at your own risk.

mira provides tooling for simple object detection projects. The package spans three areas of focus.

- **Core** object detection abstractions for images and annotations
- Access to **datasets** from common formats (e.g., VOC, COCO) and image sets (e.g., VOC 2012)
- A common API to for **well-known models** (e.g., RetinaNet and YOLO)

Check out [the docs](http://faustomorales.github.io/mira).

##  Installation

```
pip install mira
```
